# Python Intelligent Agent Framework (piaf)

![pipeline status](https://gitlab.com/ornyhtorinque/piaf/badges/master/pipeline.svg)
![coverage report](https://gitlab.com/ornyhtorinque/piaf/badges/master/coverage.svg?job=coverage)


The aim of piaf is to provide a FIPA-compliant agent framework using Python.

**For now, this work is experimental and subject to changes.**

## Documentation
API documentation is available here: https://gitlab.com/ornythorinque/piaf/-/wikis/home

## Author(s)
* ornythorinque (pierredubaillay@outlook.fr)
